@@ -1,6 +1,4 @@
-extern crate arrayfire as af;
-
-use af::*;
+use arrayfire::*;
 
 #[allow(unused_variables)]
 #[allow(unused_must_use)]
@@ -15,6 +13,8 @@ fn main() {
     loop {
         wnd.draw_image(&randu::<f32>(dims), None);
 
-        if wnd.is_closed() == true { break; }
+        if wnd.is_closed() == true {
+            break;
+        }
     }
 }
