@@ -1,37 +1,39 @@
 extern crate libc;
 extern crate num;
 
-use defines::{AfError, ColorMap, ConvDomain, ConvMode, DType, InterpType, MatProp, MatchType};
-use defines::{SparseFormat, BinaryOp, RandomEngineType};
-use error::HANDLE_ERROR;
-use std::mem;
+use self::libc::{c_int, c_uint, c_void, size_t};
 use self::num::Complex;
-use num::Zero;
-use self::libc::{c_uint, c_int, size_t, c_void};
+use crate::defines::{
+    AfError, ColorMap, ConvDomain, ConvMode, DType, InterpType, MatProp, MatchType,
+};
+use crate::defines::{BinaryOp, RandomEngineType, SparseFormat};
+use crate::error::HANDLE_ERROR;
+use crate::num::Zero;
+use std::mem;
 
-pub type AfArray       = self::libc::c_longlong;
-pub type AfIndex       = self::libc::c_longlong;
-pub type CellPtr       = *const self::libc::c_void;
-pub type Complex32     = Complex<f32>;
-pub type Complex64     = Complex<f64>;
-pub type DimT          = self::libc::c_longlong;
-pub type Feat          = *const self::libc::c_void;
-pub type Intl          = self::libc::c_longlong;
-pub type MutAfArray    = *mut self::libc::c_longlong;
-pub type MutAfIndex    = *mut self::libc::c_longlong;
-pub type MutDimT       = *mut self::libc::c_longlong;
-pub type MutDouble     = *mut self::libc::c_double;
-pub type MutFeat       = *mut *mut self::libc::c_void;
+pub type AfArray = self::libc::c_longlong;
+pub type AfIndex = self::libc::c_longlong;
+pub type CellPtr = *const self::libc::c_void;
+pub type Complex32 = Complex<f32>;
+pub type Complex64 = Complex<f64>;
+pub type DimT = self::libc::c_longlong;
+pub type Feat = *const self::libc::c_void;
+pub type Intl = self::libc::c_longlong;
+pub type MutAfArray = *mut self::libc::c_longlong;
+pub type MutAfIndex = *mut self::libc::c_longlong;
+pub type MutDimT = *mut self::libc::c_longlong;
+pub type MutDouble = *mut self::libc::c_double;
+pub type MutFeat = *mut *mut self::libc::c_void;
 pub type MutRandEngine = *mut self::libc::c_longlong;
-pub type MutUint       = *mut self::libc::c_uint;
-pub type MutVoidPtr    = *mut self::libc::c_ulonglong;
-pub type MutWndHandle  = *mut self::libc::c_ulonglong;
-pub type RandEngine    = self::libc::c_longlong;
-pub type Uintl         = self::libc::c_ulonglong;
-pub type WndHandle     = self::libc::c_ulonglong;
+pub type MutUint = *mut self::libc::c_uint;
+pub type MutVoidPtr = *mut self::libc::c_ulonglong;
+pub type MutWndHandle = *mut self::libc::c_ulonglong;
+pub type RandEngine = self::libc::c_longlong;
+pub type Uintl = self::libc::c_ulonglong;
+pub type WndHandle = self::libc::c_ulonglong;
 
 #[allow(dead_code)]
-extern {
+extern "C" {
     fn af_get_size_of(size: *mut size_t, aftype: c_uint) -> c_int;
 
     fn af_alloc_host(ptr: *mut *const c_void, bytes: DimT) -> c_int;
@@ -69,42 +71,42 @@ pub fn free_host<T>(ptr: *mut T) {
 }
 
 impl From<i32> for AfError {
-    fn from(t: i32) -> AfError {
+    fn from(t: i32) -> Self {
         assert!(AfError::SUCCESS as i32 <= t && t <= AfError::ERR_UNKNOWN as i32);
         unsafe { mem::transmute(t) }
     }
 }
 
 impl From<u32> for DType {
-    fn from(t: u32) -> DType {
+    fn from(t: u32) -> Self {
         assert!(DType::F32 as u32 <= t && t <= DType::U64 as u32);
         unsafe { mem::transmute(t) }
     }
 }
 
 impl From<u32> for InterpType {
-    fn from(t: u32) -> InterpType {
+    fn from(t: u32) -> Self {
         assert!(InterpType::NEAREST as u32 <= t && t <= InterpType::BICUBIC_SPLINE as u32);
         unsafe { mem::transmute(t) }
     }
 }
 
 impl From<u32> for ConvMode {
-    fn from(t: u32) -> ConvMode {
+    fn from(t: u32) -> Self {
         assert!(ConvMode::DEFAULT as u32 <= t && t <= ConvMode::EXPAND as u32);
         unsafe { mem::transmute(t) }
     }
 }
 
 impl From<u32> for ConvDomain {
-    fn from(t: u32) -> ConvDomain {
+    fn from(t: u32) -> Self {
         assert!(ConvDomain::AUTO as u32 <= t && t <= ConvDomain::FREQUENCY as u32);
         unsafe { mem::transmute(t) }
     }
 }
 
 impl From<u32> for MatchType {
-    fn from(t: u32) -> MatchType {
+    fn from(t: u32) -> Self {
         assert!(MatchType::SAD as u32 <= t && t <= MatchType::SHD as u32);
         unsafe { mem::transmute(t) }
     }
@@ -112,22 +114,22 @@ impl From<u32> for MatchType {
 
 pub fn to_u32(t: MatProp) -> u32 {
     match t {
-        MatProp::NONE       =>  0,
-        MatProp::TRANS      =>  1,
-        MatProp::CTRANS     =>  2,
-        MatProp::UPPER      =>  32,
-        MatProp::LOWER      =>  64,
-        MatProp::DIAGUNIT  =>  128,
-        MatProp::SYM        =>  512,
-        MatProp::POSDEF     =>  1024,
-        MatProp::ORTHOG     =>  2048,
-        MatProp::TRIDIAG   =>  4096,
-        MatProp::BLOCKDIAG =>  8192,
+        MatProp::NONE => 0,
+        MatProp::TRANS => 1,
+        MatProp::CTRANS => 2,
+        MatProp::UPPER => 32,
+        MatProp::LOWER => 64,
+        MatProp::DIAGUNIT => 128,
+        MatProp::SYM => 512,
+        MatProp::POSDEF => 1024,
+        MatProp::ORTHOG => 2048,
+        MatProp::TRIDIAG => 4096,
+        MatProp::BLOCKDIAG => 8192,
     }
 }
 
 impl From<u32> for ColorMap {
-    fn from(t: u32) -> ColorMap {
+    fn from(t: u32) -> Self {
         assert!(ColorMap::DEFAULT as u32 <= t && t <= ColorMap::BLUE as u32);
         unsafe { mem::transmute(t) }
     }
@@ -211,7 +213,9 @@ impl HasAfEnum for Complex<f32> {
     type AggregateOutType = Self;
     type SobelOutType = Self;
 
-    fn get_af_dtype() -> DType { DType::C32 }
+    fn get_af_dtype() -> DType {
+        DType::C32
+    }
 }
 impl HasAfEnum for Complex<f64> {
     type InType = Self;
@@ -224,9 +228,11 @@ impl HasAfEnum for Complex<f64> {
     type AggregateOutType = Self;
     type SobelOutType = Self;
 
-    fn get_af_dtype() -> DType { DType::C64 }
+    fn get_af_dtype() -> DType {
+        DType::C64
+    }
 }
-impl HasAfEnum for f32  {
+impl HasAfEnum for f32 {
     type InType = Self;
     type BaseType = Self;
     type AbsOutType = f32;
@@ -237,9 +243,11 @@ impl HasAfEnum for f32  {
     type AggregateOutType = Self;
     type SobelOutType = Self;
 
-    fn get_af_dtype() -> DType { DType::F32 }
+    fn get_af_dtype() -> DType {
+        DType::F32
+    }
 }
-impl HasAfEnum for f64  {
+impl HasAfEnum for f64 {
     type InType = Self;
     type BaseType = Self;
     type AbsOutType = f64;
@@ -250,7 +258,9 @@ impl HasAfEnum for f64  {
     type AggregateOutType = Self;
     type SobelOutType = Self;
 
-    fn get_af_dtype() -> DType { DType::F64 }
+    fn get_af_dtype() -> DType {
+        DType::F64
+    }
 }
 impl HasAfEnum for bool {
     type InType = Self;
@@ -263,9 +273,11 @@ impl HasAfEnum for bool {
     type AggregateOutType = u32;
     type SobelOutType = i32;
 
-    fn get_af_dtype() -> DType { DType::B8  }
+    fn get_af_dtype() -> DType {
+        DType::B8
+    }
 }
-impl HasAfEnum for u8   {
+impl HasAfEnum for u8 {
     type InType = Self;
     type BaseType = Self;
     type AbsOutType = f32;
@@ -276,9 +288,11 @@ impl HasAfEnum for u8   {
     type AggregateOutType = u32;
     type SobelOutType = i32;
 
-    fn get_af_dtype() -> DType { DType::U8  }
+    fn get_af_dtype() -> DType {
+        DType::U8
+    }
 }
-impl HasAfEnum for i16  {
+impl HasAfEnum for i16 {
     type InType = Self;
     type BaseType = Self;
     type AbsOutType = f32;
@@ -289,9 +303,11 @@ impl HasAfEnum for i16  {
     type AggregateOutType = i32;
     type SobelOutType = i32;
 
-    fn get_af_dtype() -> DType { DType::S16 }
+    fn get_af_dtype() -> DType {
+        DType::S16
+    }
 }
-impl HasAfEnum for u16  {
+impl HasAfEnum for u16 {
     type InType = Self;
     type BaseType = Self;
     type AbsOutType = f32;
@@ -302,9 +318,11 @@ impl HasAfEnum for u16  {
     type AggregateOutType = u32;
     type SobelOutType = i32;
 
-    fn get_af_dtype() -> DType { DType::U16 }
+    fn get_af_dtype() -> DType {
+        DType::U16
+    }
 }
-impl HasAfEnum for i32  {
+impl HasAfEnum for i32 {
     type InType = Self;
     type BaseType = Self;
     type AbsOutType = f32;
@@ -315,9 +333,11 @@ impl HasAfEnum for i32  {
     type AggregateOutType = i32;
     type SobelOutType = i32;
 
-    fn get_af_dtype() -> DType { DType::S32 }
+    fn get_af_dtype() -> DType {
+        DType::S32
+    }
 }
-impl HasAfEnum for u32  {
+impl HasAfEnum for u32 {
     type InType = Self;
     type BaseType = Self;
     type AbsOutType = f32;
@@ -328,9 +348,11 @@ impl HasAfEnum for u32  {
     type AggregateOutType = u32;
     type SobelOutType = i32;
 
-    fn get_af_dtype() -> DType { DType::U32 }
+    fn get_af_dtype() -> DType {
+        DType::U32
+    }
 }
-impl HasAfEnum for i64  {
+impl HasAfEnum for i64 {
     type InType = Self;
     type BaseType = Self;
     type AbsOutType = f64;
@@ -341,9 +363,11 @@ impl HasAfEnum for i64  {
     type AggregateOutType = Self;
     type SobelOutType = i64;
 
-    fn get_af_dtype() -> DType { DType::S64 }
+    fn get_af_dtype() -> DType {
+        DType::S64
+    }
 }
-impl HasAfEnum for u64  {
+impl HasAfEnum for u64 {
     type InType = Self;
     type BaseType = Self;
     type AbsOutType = f64;
@@ -354,26 +378,31 @@ impl HasAfEnum for u64  {
     type AggregateOutType = Self;
     type SobelOutType = i64;
 
-    fn get_af_dtype() -> DType { DType::U64 }
+    fn get_af_dtype() -> DType {
+        DType::U64
+    }
 }
 
 impl From<u32> for SparseFormat {
-    fn from(t: u32) -> SparseFormat {
+    fn from(t: u32) -> Self {
         assert!(SparseFormat::DENSE as u32 <= t && t <= SparseFormat::COO as u32);
         unsafe { mem::transmute(t) }
     }
 }
 
 impl From<u32> for BinaryOp {
-    fn from(t: u32) -> BinaryOp {
+    fn from(t: u32) -> Self {
         assert!(BinaryOp::ADD as u32 <= t && t <= BinaryOp::MAX as u32);
         unsafe { mem::transmute(t) }
     }
 }
 
 impl From<u32> for RandomEngineType {
-    fn from(t: u32) -> RandomEngineType {
-        assert!(RandomEngineType::PHILOX_4X32_10 as u32 <= t && t <= RandomEngineType::MERSENNE_GP11213 as u32);
+    fn from(t: u32) -> Self {
+        assert!(
+            RandomEngineType::PHILOX_4X32_10 as u32 <= t
+                && t <= RandomEngineType::MERSENNE_GP11213 as u32
+        );
         unsafe { mem::transmute(t) }
     }
 }
@@ -569,36 +598,60 @@ implicit!(bool, u8        =>        u8);
 
 impl Zero for Complex64 {
     fn zero() -> Self {
-        Complex64{re: 0.0, im: 0.0}
+        Self { re: 0.0, im: 0.0 }
     }
 }
 
 impl Zero for Complex32 {
     fn zero() -> Self {
-        Complex32{re: 0.0, im: 0.0}
+        Self { re: 0.0, im: 0.0 }
     }
 }
 
+///Trait qualifier to accept either real or complex typed data
 pub trait FloatingPoint {
-    fn is_real()    -> bool { false }
-    fn is_complex() -> bool { false }
+    fn is_real() -> bool {
+        false
+    }
+    fn is_complex() -> bool {
+        false
+    }
 }
 
-impl FloatingPoint for Complex<f64> { fn is_complex() -> bool { true } }
-impl FloatingPoint for Complex<f32> { fn is_complex() -> bool { true } }
-impl FloatingPoint for          f64 { fn    is_real() -> bool { true } }
-impl FloatingPoint for          f32 { fn    is_real() -> bool { true } }
+impl FloatingPoint for Complex<f64> {
+    fn is_complex() -> bool {
+        true
+    }
+}
+impl FloatingPoint for Complex<f32> {
+    fn is_complex() -> bool {
+        true
+    }
+}
+impl FloatingPoint for f64 {
+    fn is_real() -> bool {
+        true
+    }
+}
+impl FloatingPoint for f32 {
+    fn is_real() -> bool {
+        true
+    }
+}
 
+///Trait qualifier to accept real data(numbers)
 pub trait RealFloating {}
 
 impl RealFloating for f64 {}
 impl RealFloating for f32 {}
 
+///Trait qualifier to accept complex data(numbers)
 pub trait ComplexFloating {}
 
 impl ComplexFloating for Complex64 {}
 impl ComplexFloating for Complex32 {}
 
+///Trait qualifier indicating it can hold real numbers only
 pub trait RealNumber {}
 
 impl RealNumber for f64 {}
@@ -607,11 +660,12 @@ impl RealNumber for i32 {}
 impl RealNumber for u32 {}
 impl RealNumber for i16 {}
 impl RealNumber for u16 {}
-impl RealNumber for u8  {}
-impl RealNumber for bool{}
+impl RealNumber for u8 {}
+impl RealNumber for bool {}
 impl RealNumber for u64 {}
 impl RealNumber for i64 {}
 
+///Trait qualifier for the type of Arrays accepted by scan operations
 pub trait Scanable {}
 
 impl Scanable for i32 {}
@@ -619,12 +673,16 @@ impl Scanable for u32 {}
 impl Scanable for u64 {}
 impl Scanable for i64 {}
 
+/// Trait qualifier for type of Array's that are accepted
+/// by native image load/save functions.
 pub trait ImageNativeType {}
 
 impl ImageNativeType for f32 {}
 impl ImageNativeType for u16 {}
-impl ImageNativeType for u8  {}
+impl ImageNativeType for u8 {}
 
+/// Trait qualifier for type of Array's that are accepted
+/// by image processing functions especially filtering algorithms
 pub trait ImageFilterType {}
 
 impl ImageFilterType for f64 {}
@@ -633,10 +691,12 @@ impl ImageFilterType for i32 {}
 impl ImageFilterType for u32 {}
 impl ImageFilterType for i16 {}
 impl ImageFilterType for u16 {}
-impl ImageFilterType for u8  {}
-impl ImageFilterType for bool{}
+impl ImageFilterType for u8 {}
+impl ImageFilterType for bool {}
 
 // TODO Rust haven't stabilized trait aliases yet
+/// Trait qualifier for given type indicating conversion capability between
+/// grayscale and RGB triplets of data
 pub trait GrayRGBConvertible {}
 
 impl GrayRGBConvertible for f64 {}
@@ -645,9 +705,10 @@ impl GrayRGBConvertible for i32 {}
 impl GrayRGBConvertible for u32 {}
 impl GrayRGBConvertible for i16 {}
 impl GrayRGBConvertible for u16 {}
-impl GrayRGBConvertible for u8  {}
+impl GrayRGBConvertible for u8 {}
 
 // TODO Rust haven't stabilized trait aliases yet
+/// Trait qualifier for given type indicating computability of Moments
 pub trait MomentsComputable {}
 
 impl MomentsComputable for f64 {}
@@ -656,9 +717,10 @@ impl MomentsComputable for i32 {}
 impl MomentsComputable for u32 {}
 impl MomentsComputable for i16 {}
 impl MomentsComputable for u16 {}
-impl MomentsComputable for u8  {}
+impl MomentsComputable for u8 {}
 
 // TODO Rust haven't stabilized trait aliases yet
+/// Trait qualifier for given type indicating computability of Median
 pub trait MedianComputable {}
 
 impl MedianComputable for f64 {}
@@ -667,9 +729,11 @@ impl MedianComputable for i32 {}
 impl MedianComputable for u32 {}
 impl MedianComputable for i16 {}
 impl MedianComputable for u16 {}
-impl MedianComputable for u8  {}
+impl MedianComputable for u8 {}
 
 // TODO Rust haven't stabilized trait aliases yet
+/// Trait qualifier for given type indicating if edge calculations such as
+/// derivates etc. can be performed
 pub trait EdgeComputable {}
 
 impl EdgeComputable for f64 {}
@@ -678,8 +742,9 @@ impl EdgeComputable for i32 {}
 impl EdgeComputable for u32 {}
 impl EdgeComputable for i16 {}
 impl EdgeComputable for u16 {}
-impl EdgeComputable for u8  {}
+impl EdgeComputable for u8 {}
 
+/// Trait qualifier for given type indicating computability of covariance
 pub trait CovarianceComputable {}
 
 impl CovarianceComputable for f64 {}
@@ -688,6 +753,6 @@ impl CovarianceComputable for i32 {}
 impl CovarianceComputable for u32 {}
 impl CovarianceComputable for i16 {}
 impl CovarianceComputable for u16 {}
-impl CovarianceComputable for u8  {}
+impl CovarianceComputable for u8 {}
 impl CovarianceComputable for u64 {}
 impl CovarianceComputable for i64 {}
